@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::build;
-$App::gimpgitbuild::Command::build::VERSION = '0.8.0';
+$App::gimpgitbuild::Command::build::VERSION = '0.10.0';
 use strict;
 use warnings;
 use 5.014;
@@ -98,12 +98,8 @@ sub execute
     my $fh  = \*STDIN;
     my $obj = App::gimpgitbuild::API::GitBuild->new;
 
-    my $HOME             = $obj->home_dir;
-    my $install_base_dir = $obj->install_base_dir;
-    my $gegl_p           = "$install_base_dir/gegl";
-    my $babl_p           = "$install_base_dir/babl";
-    my $mypaint_p        = "$install_base_dir/libmypaint";
-    my $env              = $obj->new_env;
+    my $HOME = $obj->home_dir;
+    my $env  = $obj->new_env;
     $ENV{PATH}            = $env->{PATH};
     $ENV{PKG_CONFIG_PATH} = $env->{PKG_CONFIG_PATH};
     $ENV{XDG_DATA_DIRS}   = $env->{XDG_DATA_DIRS};
@@ -115,7 +111,7 @@ sub execute
             id        => "babl",
             git_co    => "$base_src_dir/babl/git/babl",
             url       => "$GNOME_GIT/babl",
-            prefix    => "$babl_p",
+            prefix    => $obj->babl_p,
             use_meson => 1,
         }
     );
@@ -124,7 +120,7 @@ sub execute
             id        => "gegl",
             git_co    => "$base_src_dir/gegl/git/gegl",
             url       => "$GNOME_GIT/gegl",
-            prefix    => "$gegl_p",
+            prefix    => $obj->gegl_p,
             use_meson => 1,
         }
     );
@@ -133,7 +129,7 @@ sub execute
             id        => "libmypaint",
             git_co    => "$base_src_dir/libmypaint/git/libmypaint",
             url       => "https://github.com/mypaint/libmypaint.git",
-            prefix    => "$mypaint_p",
+            prefix    => $obj->mypaint_p,
             use_meson => 0,
             branch    => "v1.3.0",
             tag       => "true",
@@ -144,7 +140,7 @@ sub execute
             id        => "mypaint-brushes",
             git_co    => "$base_src_dir/libmypaint/git/mypaint-brushes",
             url       => "https://github.com/Jehan/mypaint-brushes.git",
-            prefix    => "$mypaint_p",
+            prefix    => $obj->mypaint_p,
             use_meson => 0,
             branch    => "v1.3.x",
         }
@@ -177,7 +173,7 @@ __END__
 
 =head1 VERSION
 
-version 0.8.0
+version 0.10.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
