@@ -1,5 +1,5 @@
 package App::gimpgitbuild::Command::env;
-$App::gimpgitbuild::Command::env::VERSION = '0.8.0';
+$App::gimpgitbuild::Command::env::VERSION = '0.10.0';
 use strict;
 use warnings;
 use 5.014;
@@ -27,50 +27,6 @@ sub opt_spec
 
 }
 
-sub _do_system
-{
-    my ($args) = @_;
-
-    my $cmd = $args->{cmd};
-    print "Running [@$cmd]\n";
-    if ( system(@$cmd) )
-    {
-        die "Running [@$cmd] failed!";
-    }
-}
-
-sub _check
-{
-    return ( length( $ENV{SKIP_CHECK} ) ? "true" : "make check" );
-}
-
-sub _git_build
-{
-    my $args = shift;
-    $args->{branch} //= 'master';
-    $args->{tag}    //= 'false';
-
-    my $git_co = $args->{git_co};
-    if ( !-e "$args->{git_co}" )
-    {
-        path( $args->{git_co} )->parent->mkpath;
-        _do_system( { cmd => [qq#git clone "$args->{url}" "$git_co"#] } );
-    }
-    my $meson1 =
-qq#mkdir -p "build" && cd build && meson --prefix="$args->{prefix}" .. && ninja -j4 && ninja -j4 test && ninja -j4 install#;
-    my $autoconf1 =
-qq#NOCONFIGURE=1 ./autogen.sh && ./configure --prefix="$args->{prefix}" && make -j4 && @{[_check()]} && make install#;
-    _do_system(
-        {
-            cmd => [
-qq#cd "$git_co" && git checkout "$args->{branch}" && ($args->{tag} || git s origin "$args->{branch}") && #
-                    . ( $args->{use_meson} ? $meson1 : $autoconf1 )
-            ]
-        }
-    );
-    return;
-}
-
 sub execute
 {
     my ( $self, $opt, $args ) = @_;
@@ -100,7 +56,7 @@ __END__
 
 =head1 VERSION
 
-version 0.8.0
+version 0.10.0
 
 =begin foo return (
         [ "output|o=s", "Output path" ],
